/**
 * \file
 *
 * \brief PDA-ATL XMega mXT143E board init.
 *
 * This file contains board initialization function.
 *
 * Copyright (c) 2012 Precision Design Associates. All rights reserved.
 *
 */

#include <asf.h>
#include <board.h>
#include <conf_board.h>

#include <ioport.h>

void board_init(void)
{
	/* This function is meant to contain board-specific initialization code
	 * for, e.g., the I/O pins. The initialization can rely on application-
	 * specific board configuration, found in conf_board.h.
	 */
	ioport_configure_pin(LED0_GPIO, IOPORT_DIR_OUTPUT | IOPORT_INIT_HIGH);
	ioport_configure_pin(LED1_GPIO, IOPORT_DIR_OUTPUT | IOPORT_INIT_HIGH);
	ioport_configure_pin(LED2_GPIO, IOPORT_DIR_OUTPUT | IOPORT_INIT_HIGH);
	ioport_configure_pin(LED3_GPIO, IOPORT_DIR_OUTPUT | IOPORT_INIT_HIGH);
	
#ifdef CONF_BOARD_ENABLE_MXT143E_XPLAINED
	ioport_configure_pin(MXT143E_XPLAINED_SCK, IOPORT_DIR_OUTPUT
			| IOPORT_INIT_HIGH);
	ioport_configure_pin(MXT143E_XPLAINED_MOSI, IOPORT_DIR_OUTPUT
			| IOPORT_INIT_HIGH);
	ioport_configure_pin(MXT143E_XPLAINED_MISO, IOPORT_DIR_INPUT);
	ioport_configure_pin(MXT143E_XPLAINED_CS, IOPORT_DIR_OUTPUT
			| IOPORT_INIT_HIGH);
	ioport_configure_pin(MXT143E_XPLAINED_CHG, IOPORT_DIR_INPUT);
	ioport_configure_pin(MXT143E_XPLAINED_DC, IOPORT_DIR_OUTPUT
			| IOPORT_INIT_LOW);
	#ifndef MXT143E_XPLAINED_BACKLIGHT_DISABLE
	ioport_configure_pin(MXT143E_XPLAINED_BACKLIGHT, IOPORT_DIR_OUTPUT
			| IOPORT_INIT_LOW);
	#endif
	ioport_configure_pin(MXT143E_XPLAINED_LCD_RESET, IOPORT_DIR_OUTPUT
			| IOPORT_INIT_LOW);
			
	#if (PDA_FACTORY_PROG_AND_TEST)
	#if (!PDA_FACTORY_TEST_DEV_STANDALONE) 
	#warning Building for A3BU - Assuming offboard mXT
	// For Factory Test hold on-board MXT in reset...
	ioport_configure_pin(MXT143E_XPLAINED_MXT_RESET, IOPORT_DIR_OUTPUT | IOPORT_INIT_LOW);
	// ...and let off-board MXT come up
	ioport_configure_pin(MXT143E_XPLAINED_MXT_DUT_RESET, IOPORT_DIR_OUTPUT | IOPORT_INIT_HIGH);
	#else
	//ioport_configure_pin(MXT143E_XPLAINED_MXT_RESET, IOPORT_DIR_OUTPUT | IOPORT_INIT_LOW);
	#endif
	
	#endif

#endif

}
