/**
 * \file
 *
 * \brief PDA XMega mXT143E TM2801 board header file.
 *
 * To use this board define BOARD=USER_BOARD
 *
 * Copyright (c) 2012 Precision Design Associates.
 *
 */

 /* This file is intended to contain definitions and configuration details for
 * features and devices that are available on the board, e.g., frequency and
 * startup time for an external crystal, external memory devices, LED and USART
 * pins.
 */

#ifndef USER_BOARD_H
#define USER_BOARD_H

#include <conf_board.h>

#include <compiler.h>

// External oscillator settings.
// Uncomment and set correct values if external oscillator is used.

// External oscillator frequency
//#define BOARD_XOSC_HZ          8000000

// External oscillator type.
//!< External clock signal
//#define BOARD_XOSC_TYPE        XOSC_TYPE_EXTERNAL
//!< 32.768 kHz resonator on TOSC
//#define BOARD_XOSC_TYPE        XOSC_TYPE_32KHZ
//!< 0.4 to 16 MHz resonator on XTALS
//#define BOARD_XOSC_TYPE        XOSC_TYPE_XTAL

// External oscillator startup time
//#define BOARD_XOSC_STARTUP_US  500000



/**
 * \name LEDs
 */
//@{
#define LED0_GPIO                       IOPORT_CREATE_PIN(PORTD, 2) //PDA XMega LED1
#define LED1_GPIO                       IOPORT_CREATE_PIN(PORTD, 3) //PDA XMega LED2
#define LED2_GPIO                       IOPORT_CREATE_PIN(PORTD, 4) //PDA XMega Power
#define LED3_GPIO                       IOPORT_CREATE_PIN(PORTD, 5) //PDA XMega Status
#define LED0                            LED0_GPIO
#define LED1                            LED1_GPIO
#define LED2                            LED2_GPIO
#define LED3                            LED3_GPIO
#define LED_POWER                      LED2_GPIO
#define LED_STATUS                     LED3_GPIO
//! Number of LEDs.
#define LED_COUNT                       4
//@}

//! \name MXT143E Xplained top module
//@{
#define MXT143E_XPLAINED_TWI            &TWIC
//#define MXT143E_XPLAINED_USART_SPI      &USARTC1
#define MXT143E_XPLAINED_SPI      &SPIC
#define MXT143E_XPLAINED_CS             IOPORT_CREATE_PIN(PORTC, 4)
#define MXT143E_XPLAINED_SCK            IOPORT_CREATE_PIN(PORTC, 7)
#define MXT143E_XPLAINED_MOSI           IOPORT_CREATE_PIN(PORTC, 5)
#define MXT143E_XPLAINED_MISO           IOPORT_CREATE_PIN(PORTC, 6)
#define MXT143E_XPLAINED_CHG            IOPORT_CREATE_PIN(PORTC, 2)
#define MXT143E_XPLAINED_DC             IOPORT_CREATE_PIN(PORTC, 3)
#define MXT143E_XPLAINED_BACKLIGHT      IOPORT_CREATE_PIN(PORTF, 0)	// PDA XMega
#define MXT143E_XPLAINED_LCD_RESET      IOPORT_CREATE_PIN(PORTB, 2)	// PDA XMega

#define MXT143E_XPLAINED_MXT_RESET      IOPORT_CREATE_PIN(PORTA, 7)	// PDA XMega
#if (PDA_FACTORY_PROG_AND_TEST)
#define MXT143E_XPLAINED_MXT_DUT_RESET  IOPORT_CREATE_PIN(PORTD, 0)	// PDA XMega
#endif
//@}

//! \name Communication interfaces
//@{
#define TWIC_SDA                        IOPORT_CREATE_PIN(PORTC, 0)
#define TWIC_SCL                        IOPORT_CREATE_PIN(PORTC, 1)
#define USARTC0_RXD                     IOPORT_CREATE_PIN(PORTC, 2)
#define USARTC0_TXD                     IOPORT_CREATE_PIN(PORTC, 3)
#define SPIC_SS                         IOPORT_CREATE_PIN(PORTC, 4)
#define SPIC_MOSI                       IOPORT_CREATE_PIN(PORTC, 5)
#define SPIC_MISO                       IOPORT_CREATE_PIN(PORTC, 6)
#define SPIC_SCK                        IOPORT_CREATE_PIN(PORTC, 7)
//@}
#endif // USER_BOARD_H
